@@ -25,6 +25,7 @@ import itertools
 import math
 import numpy as np
 import os
+import shutil
 import string
 
 from dataiter import deco
@@ -54,6 +55,9 @@ def format_floats(seq):
 def generate_colnames(n):
     return list(itertools.islice(yield_colnames(), n))
 
+def get_print_width():
+    return shutil.get_terminal_size((dataiter.PRINT_MAX_WIDTH, 24))[0] - 1
+
 def length(value):
     return 1 if np.isscalar(value) else len(value)
 
@@ -78,7 +82,7 @@ def unique_keys(keys):
     return list(dict.fromkeys(keys))
 
 def unique_types(seq):
-    return set(x.__class__ for x in seq) - set((None.__class__,))
+    return set(x.__class__ for x in seq if x not in [None, np.nan])
 
 def yield_colnames():
     # Like Excel: a, b, c, ..., aa, bb, cc, ...
